from setuptools import setup

with open("README.md", "r") as fh:
    readme = fh.read()

setup(name='geracao',
    version='0.0.1',
    url='https://github.com/DiegoAbreu/geracao',
    license='MIT License',
    author='Diego Abreu',
    long_description=readme,
    long_description_content_type="text/markdown",
    author_email='',
    keywords=['geracao', 'cpf'],
    description=u'Pacote para geracao de dados',
    packages=['geracao'],
    install_requires=[],)


# Função de geração de CPFs: 
from random import randint
def cpf(quantidade):
    lista_cpf =[]
    for i in range(0,quantidade):
        while True:
            num_cpf = [randint(0, 9) for i in range(9)]
            if num_cpf != num_cpf[::-1]:
                break
        for i in range(9, 11):
            calculo = sum((num_cpf[num] * ((i + 1) - num) for num in range(0, i)))
            digito = ((calculo * 10) % 11) % 10
            num_cpf.append(digito)
        lista_cpf.append(str(''.join(map(str, num_cpf))))
    return lista_cpf